@@ -8,8 +8,6 @@ Interface Classes:
     VectorFunction
 """
 
-__copyright__ = "Copyright (c) 2012, Chris Drake"
-
 from pyeda.common import iter_space
 
 
@@ -307,7 +305,7 @@ class VectorFunction(Slicer):
         all functions.
         """
         items = [f.restrict(mapping) for f in self]
-        return self.__class__(items, (self.start, self.stop))
+        return self.__class__(items, self.start)
 
     def vrestrict(self, mapping):
         """Expand all vectors before applying 'restrict'."""
